<?php

declare(strict_types=1);

namespace Dedi\SyliusAvisVerifiesPlugin\Client;

use Dedi\SyliusAvisVerifiesPlugin\Exception\BadSignatureException;
use Dedi\SyliusAvisVerifiesPlugin\Exception\UnknownWebsiteIdException;
use Symfony\Component\HttpFoundation\Exception\BadRequestException;
use Symfony\Contracts\HttpClient\HttpClientInterface as BaseHttpClientInterface;

final class HttpClient implements HttpClientInterface
{
    private BaseHttpClientInterface $client;

    public function __construct(
        BaseHttpClientInterface $client,
    ) {
        $this->client = $client;
    }

    public function post(string $url, array $body): void
    {
        $response = $this->client->request('POST', $url, [
            'body' => $body,
        ]);

        $responseData = $response->toArray();
        switch ($responseData['return']) {
            case 1:
                return;
            case 2:
                throw new BadSignatureException(\json_encode($body));
            case 3:
                throw new UnknownWebsiteIdException(\json_encode($body));
            case 4:
            default:
                throw new BadRequestException(\json_encode($body));
        }
    }
}
